@@ -20,6 +20,7 @@ import re
 
 from oslo_serialization import jsonutils
 from oslo_utils import strutils
+from oslo_utils import timeutils
 
 from blazarclient import command
 from blazarclient import exception
@@ -52,22 +53,18 @@ CREATE_RESERVATION_KEYS = {
         "resource_properties": "",
         "resource_type": 'virtual:instance'
     },
+    "flavor:instance": {
+        "flavor_id": "",
+        "amount": "",
+        "affinity": "None",
+        "resource_type": 'flavor:instance'
+    },
     "others": {
         ".*": None
     }
 }
 
 
-def _utc_now():
-    """Wrap datetime.datetime.utcnow so it can be mocked in unit tests.
-
-    This is required because some of the tests require understanding the
-    'current time'; simply mocking utcnow() is made very difficult by
-    the many different ways the datetime package is used in this module.
-    """
-    return datetime.datetime.utcnow()
-
-
 class ListLeases(command.ListCommand):
     """Print a list of leases."""
     resource = 'lease'
@@ -90,6 +87,16 @@ class ShowLease(command.ShowCommand):
     json_indent = 4
     log = logging.getLogger(__name__ + '.ShowLease')
 
+    def get_parser(self, prog_name):
+        parser = super(ShowLease, self).get_parser(prog_name)
+        if self.allow_names:
+            help_str = 'ID or name of %s to look up'
+        else:
+            help_str = 'ID of %s to look up'
+        parser.add_argument('id', metavar=self.resource.upper(),
+                            help=help_str % self.resource)
+        return parser
+
 
 class CreateLeaseBase(command.CreateCommand):
     """Create a lease."""
@@ -97,7 +104,7 @@ class CreateLeaseBase(command.CreateCommand):
     json_indent = 4
     log = logging.getLogger(__name__ + '.CreateLease')
     default_start = 'now'
-    default_end = _utc_now() + datetime.timedelta(days=1)
+    default_end = timeutils.utcnow() + datetime.timedelta(days=1)
 
     def get_parser(self, prog_name):
         parser = super(CreateLeaseBase, self).get_parser(prog_name)
@@ -173,7 +180,7 @@ class CreateLeaseBase(command.CreateCommand):
                 raise exception.IncorrectLease
 
         if parsed_args.start == 'now':
-            start = _utc_now()
+            start = timeutils.utcnow()
         else:
             start = parsed_args.start
 
@@ -216,6 +223,8 @@ class CreateLeaseBase(command.CreateCommand):
                 defaults = CREATE_RESERVATION_KEYS['virtual:instance']
             elif "virtual:floatingip" in res_str:
                 defaults = CREATE_RESERVATION_KEYS['virtual:floatingip']
+            elif "flavor:instance" in res_str:
+                defaults = CREATE_RESERVATION_KEYS['flavor:instance']
             else:
                 defaults = CREATE_RESERVATION_KEYS['others']
 
